@@ -160,10 +160,10 @@ gboolean jump_dialog(JumpDialog *jmp)
 									G_CALLBACK (jump_dialog_changed), jmp);
 	gtk_editable_select_region(GTK_EDITABLE(entry),0,-1);
 	/* ե졼ȥܥå */
-	vbox=gtk_vbox_new(FALSE,8);
-	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
+	vbox = gtk_vbox_new (FALSE, SPACING);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
 	gtk_box_pack_start(GTK_BOX(vbox),entry,TRUE,TRUE,0);
-	hbox=gtk_hbox_new(FALSE,8);
+	hbox = gtk_hbox_new (FALSE, SPACING);
 	gtk_box_pack_end(GTK_BOX(hbox),button1,FALSE,FALSE,0);
 	gtk_box_pack_end(GTK_BOX(hbox),button0,FALSE,FALSE,0);
 	gtk_box_pack_end(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
