@@ -23,19 +23,29 @@
 #include "tmaid.h"
 
 
-/*	vpeBRs[
-	ft_dst,Rs[
-	ft_src,Rs[															*/
+/******************************************************************************
+*                                                                             *
+* ץѥƥؿ                                                            *
+*                                                                             *
+******************************************************************************/
+/*	ץѥƥ򥳥ԡ
+	ft_dst,ԡ
+	ft_src,ԡ															*/
 void
 property_copy (FileType *ft_dst, FileType *ft_src);
 
 
-/*	vpeBύX
-	tmaid,TXTEChE
-	   ft,t@C^Cv													*/
+/*	ץѥƥѹ
+	tmaid,TXTɥ
+	   ft,ե륿													*/
 void property_change(TmaidWindow *tmaid,FileType *ft);
 
 
+/******************************************************************************
+*                                                                             *
+* ץѥƥؿ                                                  *
+*                                                                             *
+******************************************************************************/
 gboolean property_dialog(FileType *ft);
 
 
