@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
 typedef struct ToolBar_Tag {
 	gchar *name;
 	gchar **xpm;
-	GtkSignalFunc callback;
+	GtkItemFactoryCallback callback;
 	gpointer user_data;
 	GtkWidget *item;
 } ToolBar;
