@@ -23,19 +23,10 @@
 
 /******************************************************************************
 *                                                                             *
-* Сؿ                                                        *
+* バージョン情報関数群                                                        *
 *                                                                             *
 ******************************************************************************/
-/* 饸ܥѹ줿 */
-static void
-version_dialog_toggled (GtkWidget *widget, GtkWidget *widgets[])
-{
-	gtk_widget_show (widgets[0]);
-	gtk_widget_hide (widgets[1]);
-}
-
-
-/* ESC줿 */
+/* ESCが押された */
 static gboolean version_dialog_key_press(GtkWidget *widget,GdkEventKey *event,
 															gpointer user_data)
 {
@@ -47,14 +38,12 @@ static gboolean version_dialog_key_press(GtkWidget *widget,GdkEventKey *event,
 
 void version_dialog(void)
 {
-	guint key;
 	GdkPixmap *pixmap;
 	GdkBitmap *mask;
-	GtkAccelGroup *accel;
 	GtkTextBuffer *buffer;
-	GtkWidget *dialog, *button, *hbox0, *hbox1, *vbox;
-	GtkWidget *text0, *text1, *scroll0, *scroll1, *radio0, *radio1;
-	GtkWidget *widget0[2], *widget1[2];
+    GtkTextIter where;
+	GtkWidget *dialog, *button, *notebook, *hbox0, *hbox1, *vbox;
+	GtkWidget *text, *scroll;
 const static gchar *authors =
 "Main Program :\n"
 "    Kazuki IWAMOTO\n"
@@ -114,7 +103,7 @@ static gchar *tmaid_xpm[] = {
 "  +$$$$$+$$$$$$;$$$$$$+$$$$$+   ",
 "  +$$$$$+$$$$$$$$$$$$$+$$$$$+   "};
 
-	/* ᥤ󥦥ɥ */
+	/* メインウインドウ */
 	dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title(GTK_WINDOW(dialog),_("About Text maid"));
 	gtk_window_set_default_size (GTK_WINDOW (dialog),
@@ -123,55 +112,54 @@ static gchar *tmaid_xpm[] = {
 								G_CALLBACK (version_dialog_key_press), NULL);
 	g_signal_connect (G_OBJECT (dialog), "destroy",
 											G_CALLBACK (gtk_main_quit), NULL);
-	/* 졼 */
-	accel = gtk_accel_group_new ();
-	gtk_window_add_accel_group (GTK_WINDOW (dialog), accel);
-	/* ܥ */
+    /* ja:ノートブック */
+    notebook = gtk_notebook_new ();
+    gtk_notebook_set_scrollable (GTK_NOTEBOOK (notebook), TRUE);
+    gtk_notebook_set_tab_pos (GTK_NOTEBOOK (notebook), n_pos);
+
+    /* ja:ライセンス */
+    /* ja:テキスト */
+    text = gtk_text_view_new ();
+    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (text));
+    gtk_text_buffer_set_text (buffer, gnu_gpl, -1);
+    gtk_text_buffer_get_start_iter (buffer, &where);
+    gtk_text_buffer_place_cursor (buffer, &where);
+    gtk_text_view_set_editable (GTK_TEXT_VIEW (text), FALSE);
+    /* ja:スクロールウインドウ */
+    scroll = gtk_scrolled_window_new (NULL, NULL);
+    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll),
+                                GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+    gtk_container_add (GTK_CONTAINER (scroll), text);
+    /* ja:ノートブック */
+    gtk_notebook_append_page (GTK_NOTEBOOK (notebook), scroll,
+                                                gtk_label_new (_("License")));
+
+    /* ja:作者 */
+    /* ja:テキスト */
+    text = gtk_text_view_new ();
+    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (text));
+    gtk_text_buffer_set_text (buffer, authors, -1);
+    gtk_text_buffer_get_start_iter (buffer, &where);
+    gtk_text_buffer_place_cursor (buffer, &where);
+    gtk_text_view_set_editable (GTK_TEXT_VIEW (text), FALSE);
+    /* ja:スクロールウインドウ */
+    scroll = gtk_scrolled_window_new (NULL, NULL);
+    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll),
+                                GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+    gtk_container_add (GTK_CONTAINER (scroll), text);
+    /* ja:ノートブック */
+    gtk_notebook_append_page (GTK_NOTEBOOK (notebook), scroll,
+                                                gtk_label_new (_("Authors")));
+
+	/* ボタン */
 	button=gtk_button_new_with_label(_("OK"));
 	g_signal_connect_swapped (G_OBJECT (button), "clicked",
 						G_CALLBACK (gtk_widget_destroy), G_OBJECT (dialog));
 	GTK_WIDGET_SET_FLAGS(button,GTK_CAN_DEFAULT);
-	/* ƥ */
-	text0 = gtk_text_view_new ();
-	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (text0));
-	gtk_text_buffer_set_text (buffer, gnu_gpl, -1);
-	gtk_text_view_set_editable (GTK_TEXT_VIEW (text0), FALSE);
-	text1 = gtk_text_view_new ();
-	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (text1));
-	gtk_text_buffer_set_text (buffer, authors, -1);
-	gtk_text_view_set_editable (GTK_TEXT_VIEW (text1), FALSE);
-	/* 륦ɥ */
-	scroll0 = gtk_scrolled_window_new (NULL, NULL);
-	scroll1 = gtk_scrolled_window_new (NULL, NULL);
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll0),
-								GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll1),
-								GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	gtk_container_add (GTK_CONTAINER (scroll0), text0);
-	gtk_container_add (GTK_CONTAINER (scroll1), text1);
-	/* 饸ܥ */
-	widget0[0] = widget1[1] = scroll0;
-	widget0[1] = widget1[0] = scroll1;
-	radio0 = gtk_radio_button_new_with_label (NULL, "");
-	radio1 = gtk_radio_button_new_with_label_from_widget
-											(GTK_RADIO_BUTTON (radio0), "");
-	key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (radio0)->child),
-																_("_License"));
-	gtk_widget_add_accelerator (radio0, "clicked", accel, key,
-															GDK_MOD1_MASK, 0);
-	key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (radio1)->child),
-																_("_Authors"));
-	gtk_widget_add_accelerator (radio1, "clicked", accel, key,
-															GDK_MOD1_MASK, 0);
-	g_signal_connect (G_OBJECT (radio0), "toggled",
-								G_CALLBACK (version_dialog_toggled), widget0);
-	g_signal_connect (G_OBJECT (radio1), "toggled",
-								G_CALLBACK (version_dialog_toggled), widget1);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio0), TRUE);
-	/* ԥޥå */
+	/* ピクスマップ */
 	pixmap=gdk_pixmap_create_from_xpm_d(window->window,&mask,NULL,tmaid_xpm);
 
-	/* ե졼ȥܥå */
+	/* フレームとボックス */
 	vbox = gtk_vbox_new (FALSE, SPACING);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
 	hbox0 = gtk_hbox_new (FALSE, SPACING);
@@ -183,23 +171,17 @@ static gchar *tmaid_xpm[] = {
 	hbox1 = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (hbox1), hbox0, TRUE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), hbox1, FALSE, FALSE, 0);
-	hbox0 = gtk_hbox_new (FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (hbox0), widget0[0], TRUE, TRUE, 0);
-	gtk_box_pack_start (GTK_BOX (hbox0), widget0[1], TRUE, TRUE, 0);
-	gtk_box_pack_start (GTK_BOX (vbox), hbox0, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), notebook, TRUE, TRUE, 0);
 	hbox0 = gtk_hbox_new (FALSE, SPACING);
-	gtk_box_pack_start (GTK_BOX (hbox0), radio0, FALSE, FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (hbox0), radio1, FALSE, FALSE, 0);
 	gtk_box_pack_end (GTK_BOX (hbox0), button, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (vbox), hbox0, FALSE, FALSE, 0);
 	gtk_container_add(GTK_CONTAINER(dialog),vbox);
 
-	/* ɽ */
+	/* 表示 */
 	gtk_widget_grab_focus(button);
 
 	gtk_window_set_policy(GTK_WINDOW(dialog),FALSE,TRUE,FALSE);
 	gtk_grab_add(dialog);
 	gtk_widget_show_all(dialog);
-	gtk_widget_hide (widget0[1]);
 	gtk_main();
 }
